@@ -5,7 +5,7 @@
        ## must use full access of :::
      }
 
-mmseg4j <- function (text, method = c("complex", "maxword", "simple"), dicDir = NULL, reload = FALSE)
+mmseg4j <- function (text, method = c("complex", "maxword", "simple"), dicDir = NULL)
 {
     ## the plugins are from http://code.google.com/p/mmseg4j/
     ## this segmentation softeware seems most useful
@@ -18,11 +18,15 @@ mmseg4j <- function (text, method = c("complex", "maxword", "simple"), dicDir =
     if (method=="maxword")  mmseg <- .jnew("Rmmseg4j/RmmsegMaxWord")
     if (method=="simple")  mmseg <- .jnew("Rmmseg4j/RmmsegSimple")
     if (!is.null(dicDir)) {
-        mmseg$dic <- mmseg$dic$getInstance(dicDir)
+        mmseg$resetDefaultDicPath(dicDir)
     } else {
-        mmseg$dic <-  mmseg$dic$getInstance(file.path(system.file(package = "rmmseg4j"), "userDic"))
+        mmseg$resetDefaultDicPath(file.path(system.file(package = "rmmseg4j"), "userDic"))
     }
-    if (reload) mmseg$dic$reload()
+    if (isTRUE(mmseg$needReload())) {
+        succeeded <- mmseg$reloadDic()
+        if (!succeeded) warning("Fail to reload the changed dictionary")
+        }
+    ## automatically examine the status of dic, reload if changed
     for (i in seq_len(N)) {
         Val <- mmseg$segWords(text[i], " ")
         Encoding(Val) <- "UTF-8"
